from invenio_records.systemfields import ConstantField
from invenio_drafts_resources.records import ParentRecordStateMixin
from {{ current_model.drafts_parent_record_metadata_class|package_name }} import {{ current_model.drafts_parent_record_metadata_class|base_name }}
from {{ current_model.drafts_parent_record_parent_class|package_name }} import {{ current_model.drafts_parent_record_parent_class|base_name }}

class {{ current_model.drafts_parent_record_class|base_name }}({{ current_model.drafts_parent_record_parent_class|base_name }}): #TODO create special name for these? assuming yes

    model_cls = {{ current_model.drafts_parent_record_metadata_class|base_name }}

    schema = ConstantField(
        "$schema", "{{ current_model.schema_server }}{{ current_model.drafts_parent_schema_name }}"
    )