TEMPLATES = {
    "drafts-record-extra-fields": "templates/invenio_drafts_record_extra_fields.py.jinja2",                            #adds drafts extension fields to record
    "drafts-record-metadata-extra-fields": "templates/invenio_drafts_record_metadata_extra_fields.py.jinja2",  # adds parent specific fields to model metadata classes

    "drafts-parent-record": "templates/invenio_drafts_parent_record.py.jinja2",              #adds draft parent record class
    "drafts-parent-metadata": "templates/invenio_drafts_parent_metadata.py.jinja2",            #adds draft parent metadata classes

    "drafts-record-service-config": "templates/invenio_drafts_record_service_config.py.jinja2",
    "drafts-parent-state": "templates/invenio_drafts_parent_state.py.jinja2"
}